#ifndef OPTION_H_
#define OPTION_H_

#include <stdexcept>
#include <iostream>
#include <fstream>
#include <sstream>
#include <string>

class Option {
public:
   // user defined exception class
   struct InvalidArgument:public std::invalid_argument {
      InvalidArgument():std::invalid_argument(
           "Usage: ./NDComplexGO <-i file name> [options], do './NDComplexGO -h' for help") {}
   };
  
private:
   std::string	input_file;
   std::string	output_file;
   bool			show_help;
   double		tt;
   int			ct;
   double		dt;
   double		st;
   bool			hasoutputfile;

public:  
	Option() : input_file("network.example"), output_file("network.example.t0.3.c3.d0.7.s0.2.out"), tt(0.3), ct(3), dt(0.7), st(0.2),
	 show_help(false), hasoutputfile(false) {}
  
	/* initialize options according to command line */
	void init(int argc, char** argv)
		throw (InvalidArgument);
  
	/* accessor functions */
	const std::string getInputFile() const { return input_file; }
	const std::string getOutputFile() const { return output_file; }
	const double getCliquesSimilarityThreshold() const {return tt; }
	const int getCliquesCutSizeThreshold() const {return ct; }
	const double getDensityThreshold() const {return dt; }
	const double getSimilarityThreshold() const {return st; }
	/* other functions */
	bool showHelp() const { return show_help; }
  
	/* print help message */
	void printUsage() const;
};

#endif // OPTION_H_
